/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLElement.h"
#include "HTMLTableRowElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLTableRowElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLTableRowElement.h"
#include "gdom/PrivateIntGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLTableRowElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLTableRowElement::GDOMHTMLTableRowElement(PassRefPtr<WebCore::HTMLTableRowElement> impl)
    : GDOMHTMLElement(impl)
{
}

GdomHTMLElement *
gdom_html_table_row_element_insert_cell (GdomHTMLTableRowElement *thiz, glong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::HTMLTableRowElement * item = (gdom_html_table_row_element_get_private(thiz));
    g_return_val_if_fail (item, 0);
    WebCore::ExceptionCode ec = 0;
    PassRefPtr<WebCore::HTMLElement> g_res = WTF::getPtr(item->insertCell(index, ec));
    GdomHTMLElement * res = static_cast<GdomHTMLElement *>(WebCore::toGDOM(g_res.get()));
    return res;

}

void
gdom_html_table_row_element_delete_cell (GdomHTMLTableRowElement *thiz, glong index)
{
    g_return_if_fail (thiz);
    WebCore::HTMLTableRowElement * item = (gdom_html_table_row_element_get_private(thiz));
    g_return_if_fail (item);
    WebCore::ExceptionCode ec = 0;
    item->deleteCell(index, ec);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLTableRowElement.h"
#include <gdom/GdomHTMLTableRowElement.h>
#include <gdom/PrivateGdomHTMLTableRowElement.h>
#include <gdom/PrivateIntGdomHTMLTableRowElement.h>
#include <gdom/GdomHTMLTableRowElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLTableRowElement, gdom_html_table_row_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLTableRowElementPrivate {
    class WebCore::HTMLTableRowElement *item;
};

#define GDOM_HTML_TABLE_ROW_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_TABLE_ROW_ELEMENT, GdomHTMLTableRowElementPrivate))
*/
G_END_DECLS
WebCore::HTMLTableRowElement *
gdom_html_table_row_element_get_private(GdomHTMLTableRowElement *request)
{
    GDOMHTMLTableRowElement *res;
    res = static_cast<GDOMHTMLTableRowElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLTableRowElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ROW_INDEX,
    PROP_SECTION_ROW_INDEX,
    PROP_CELLS,
    PROP_ALIGN,
    PROP_BG_COLOR,
    PROP_CH,
    PROP_CH_OFF,
    PROP_V_ALIGN,
};


static void gdom_html_table_row_element_finalize(GObject* object)
{
    /*GdomHTMLTableRowElement* request = GDOM_HTML_TABLE_ROW_ELEMENT(object);*/
    /*GdomHTMLTableRowElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_table_row_element_parent_class)->finalize(object);
}

static void gdom_html_table_row_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableRowElement *self = GDOM_HTML_TABLE_ROW_ELEMENT(object);
    WebCore::HTMLTableRowElement * gself = (gdom_html_table_row_element_get_private(self));
    switch (prop_id) {
     case PROP_ALIGN:
    {
         gself->setAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_BG_COLOR:
    {
         gself->setBgColor(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH:
    {
         gself->setCh(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CH_OFF:
    {
         gself->setChOff(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_V_ALIGN:
    {
         gself->setVAlign(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_row_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLTableRowElement *self = GDOM_HTML_TABLE_ROW_ELEMENT(object);
    WebCore::HTMLTableRowElement * gself = (gdom_html_table_row_element_get_private(self));
    switch (prop_id) {
    case PROP_ROW_INDEX:
    {
         g_value_set_long (value, gself->rowIndex());
         break;
    }
    case PROP_SECTION_ROW_INDEX:
    {
         g_value_set_long (value, gself->sectionRowIndex());
         break;
    }
    case PROP_CELLS:
    {
         PassRefPtr<WebCore::HTMLCollection> ptr = gself->cells();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->align()));
         break;
    }
    case PROP_BG_COLOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->bgColor()));
         break;
    }
    case PROP_CH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->ch()));
         break;
    }
    case PROP_CH_OFF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->chOff()));
         break;
    }
    case PROP_V_ALIGN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->vAlign()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_table_row_element_class_init(GdomHTMLTableRowElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_table_row_element_finalize;
    g_klass->set_property = gdom_html_table_row_element__set_property_fn;
    g_klass->get_property = gdom_html_table_row_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ROW_INDEX,
            g_param_spec_long ("row_index", /* name */
                "html_table_row_element_row_index", /* short description */
                "read-only  glong HTMLTableRowElement.row_index", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SECTION_ROW_INDEX,
            g_param_spec_long ("section_row_index", /* name */
                "html_table_row_element_section_row_index", /* short description */
                "read-only  glong HTMLTableRowElement.section_row_index", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_CELLS,
            g_param_spec_object ("cells", /* name */
                "html_table_row_element_cells", /* short description */
                "read-only  GdomHTMLCollection * HTMLTableRowElement.cells", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_HTML_COLLECTION, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ALIGN,
            g_param_spec_string ("align", /* name */
                "html_table_row_element_align", /* short description */
                "read-write  gchar * HTMLTableRowElement.align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_BG_COLOR,
            g_param_spec_string ("bg_color", /* name */
                "html_table_row_element_bg_color", /* short description */
                "read-write  gchar * HTMLTableRowElement.bg_color", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH,
            g_param_spec_string ("ch", /* name */
                "html_table_row_element_ch", /* short description */
                "read-write  gchar * HTMLTableRowElement.ch", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CH_OFF,
            g_param_spec_string ("ch_off", /* name */
                "html_table_row_element_ch_off", /* short description */
                "read-write  gchar * HTMLTableRowElement.ch_off", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_V_ALIGN,
            g_param_spec_string ("v_align", /* name */
                "html_table_row_element_v_align", /* short description */
                "read-write  gchar * HTMLTableRowElement.v_align", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLTableRowElementPrivate));*/
}

static void gdom_html_table_row_element_init(GdomHTMLTableRowElement* request)
{
    /*GdomHTMLTableRowElementPrivate* priv = GDOM_HTML_TABLE_ROW_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

